@@ -13,7 +13,7 @@ from ForMark.singleton import Singleton
 # log_file_path = os.path.join(BASE_DIR, 'log/bb.log')
 
 class ForLog(Singleton):
-    def __init__(self, log_file_path="/logs/mark"):
+    def __init__(self, log_file_path):
         logger.add(
             log_file_path,
             format="{time:YYYY-MM-DD at HH:mm:ss} | {level} | {message}",
